<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>Raggio valido</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>Nessuna soluzione</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Selezionare entità o regione</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Spostare entità o riferimento</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Impostare secondo angolo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Specificare il punto finale di punto di riferimento</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Specificare il punto finale della selezione</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Spostare entità</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Spostare riferimento</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Spostare selezione</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Spostare entità</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Modifica blocco &apos;%1&apos;&lt;br&gt;Scegliete &lt;i&gt;Blocco &gt; Torna al disegno principale&lt;/i&gt; quando fatto</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Strumento attivo:</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Niente</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Opzioni blocco</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Strumenti principali</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>Strumenti CAD</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità è su un layer bloccato.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Lunghezza:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità non è un riferimento di blocco.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità non è una linea o un arco.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>Entità non è una linea, un arco o un polilinea.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità non è una linea.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità non è un arco o un cerchio.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità non è una linea, un arco o un cerchio.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità non è un arco, un cerchio o un&apos;ellisse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Entità non è una linea, un arco, un cerchio o un&apos;ellisse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Entità non è una linea, un arco, un cerchio, un ellisse o polilinea.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Entità non è una linea, un arco, un cerchio, un ellisse o una spline.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Entità non è una linea, un arco, un cerchio, un ellisse, una spline o polilinea.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità non è una polilinea.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Raggio è sceso sotto 0,0 dopo %1 cerchi concentrico.</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Raggio è sceso sotto 0,0 dopo %1 archi concentrici.</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Almeno due punti sono identici.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nessun cerchio possibile.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Nessun arco possibile.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Non valido numero di segmenti:.%1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Non valido ellisse maggiori / minori: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Ripristina predefiniti</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Inserisci Simbolo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Diametro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Arco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Gradi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Plus / minus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Quasi uguale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Asintoticamente uguale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Radice quadrata</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>Alt phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Moltiplicazione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Divisione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Quadrato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Testo impilato</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Valore misurato</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Allineato</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Fit</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Base</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Sotto</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation>Senso orario</translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation>Senso antiorario</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation>Niente</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <source>Loading plugins...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Caricamento plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins...</source>
        <translation type="obsolete">Inizializzazione plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Inizializzazione plugins:</translation>
    </message>
    <message>
        <source>Post-initializing plugins...</source>
        <translation type="obsolete">Inizializzazione plugins...</translation>
    </message>
    <message>
        <source>Post-Initialization...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Post-inizializzazione...</translation>
    </message>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Caricamento aggiuntivo traduzioni...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Caricamento add-ons...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Inizializzazione add-ons...</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Post-inizializzazione...</translation>
    </message>
    <message>
        <source>Loading add-on translations ...</source>
        <translation type="obsolete">Caricamento add-on traduzioni ...</translation>
    </message>
    <message>
        <source>Loading add-ons ...</source>
        <translation type="obsolete">Caricamento add-ons ...</translation>
    </message>
    <message>
        <source>Initializing add-ons ...</source>
        <translation type="obsolete">Inizializzazione add-ons ...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Inizializzazione add-ons:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons ...</source>
        <translation type="obsolete">Post-inizializzazione ...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Oggetti</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Oggetto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Oggetti sconosciuta</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Oggetto sconosciuta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Blocchi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Blocco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>Layouts</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Tipi di linea</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Tipo di linea</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Viste</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Entità</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Entità</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>3dFaces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>3dFace</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Riferimenti di blocco</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translatorcomment>--google--
Scegliere il riferimento di blocco
Modificare un blocco sulla base di un riferimento di blocco scelto</translatorcomment>
        <translation>Riferimento di blocco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Riferimenti di blocco e attributi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Riferimento di blocco e attributi</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>Archi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>Arco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Attributi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Attributo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Definizioni degli attributi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Definizione di attributo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>Cerchi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>Cerchio</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Quote</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Quota</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimension</source>
        <translation>Quota allineata</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Quote allineate</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimension</source>
        <translation>Quota angolare</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimensions</source>
        <translation>Quote angolari</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation>Quote angolari 2 linee</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation>Quota angolare 2 linee</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation>Quote angolari 3 punti</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation>Quota angolare 3 punti</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation>Dimensione d&apos;arco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimension</source>
        <translation>Quota diametro</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Quote diametro</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimension</source>
        <translation>Quota coordinata</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Quote coordinata</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Quote ruotate</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Quota ruotata</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimension</source>
        <translation>Quota radiale</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Quote raggio</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>Ellissi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>Ellisse</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translation>Tratteggi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translation>Tratteggio</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translation>Immagine</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leader</source>
        <translation>Direttrice</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leaders</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Direttrici</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>Linee</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Linee Infinite</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Linea infinita</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Raggi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Raggio</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Punti</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Polilinee</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Polilinea</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solid</source>
        <translation>Solido</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solids</source>
        <translatorcomment>--google--
in linee, solidi e testi</translatorcomment>
        <translation>Solidi</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Traccias</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Traccia</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>Faccias</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>Faccia</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Basato su testo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>Testi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Finestre</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità sconosciuta</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità sconosciuta</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Prima entità non può essere tagliato.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Entità non può essere tagliato.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Seconda entità non può essere tagliato.</translation>
    </message>
</context>
</TS>
